aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--bash/bash_profile.d/remind.bash6
1 files changed, 4 insertions, 2 deletions
diff --git a/bash/bash_profile.d/remind.bash b/bash/bash_profile.d/remind.bash
index 7188c639..3f9908a0 100644
--- a/bash/bash_profile.d/remind.bash
+++ b/bash/bash_profile.d/remind.bash
@@ -1,5 +1,7 @@
-# If interactive and rem(1) installed, run it
-if [[ $- == *i* ]] && hash rem 2>/dev/null ; then (
+# If interactive, ~/.reminders, and rem(1), run it
+if [[ $- == *i* ]] && \
+ [[ -e $HOME/.reminders ]] && \
+ hash rem 2>/dev/null ; then (
while read -r reminder ; do
printf '* %s\n' "$reminder"
done < <(rem -hq)